@@ -2,9 +2,13 @@
 Interface for symbols
 """
 
+from __future__ import annotations
 import abc
 
-from typing import Optional
+from typing import Optional, Iterable, TYPE_CHECKING
+
+if TYPE_CHECKING:
+    from dragodis.interface import Reference
 
 
 class Symbol(metaclass=abc.ABCMeta):
@@ -26,6 +30,13 @@ class Symbol(metaclass=abc.ABCMeta):
         Name of the symbol
         """
 
+    @property
+    @abc.abstractmethod
+    def references_to(self) -> Iterable[Reference]:
+        """
+        References to symbol
+        """
+
 
 class Import(Symbol):
     """
